// יצירת אלמנט התצוגה המקדימה
const previewElement = document.createElement('div');
previewElement.className = 'video-preview';
previewElement.innerHTML = `
    <video autoplay muted loop></video>
    <div class="preview-info"></div>
    <div class="preview-loading">טוען תצוגה מקדימה...</div>
    <div class="preview-error"></div>
`;
document.body.appendChild(previewElement);

const previewVideo = previewElement.querySelector('video');
const previewInfo = previewElement.querySelector('.preview-info');
const previewLoading = previewElement.querySelector('.preview-loading');
const previewError = previewElement.querySelector('.preview-error');

// פונקציה להמרת שניות לפורמט של זמן
function formatDuration(seconds) {
    const hours = Math.floor(seconds / 3600);
    const minutes = Math.floor((seconds % 3600) / 60);
    const remainingSeconds = Math.floor(seconds % 60);
    
    if (hours > 0) {
        return `${hours}:${minutes.toString().padStart(2, '0')}:${remainingSeconds.toString().padStart(2, '0')}`;
    }
    return `${minutes}:${remainingSeconds.toString().padStart(2, '0')}`;
}

// פונקציה לטיפול בקובץ ZIP
async function handleZipFile(url, preview = false) {
    const response = await fetch(url);
    const zipData = await response.arrayBuffer();
    
    const zip = new JSZip();
    const zipContent = await zip.loadAsync(zipData);
    
    for (const fileName in zipContent.files) {
        if (fileName.toLowerCase().endsWith('.mp4')) {
            const videoFile = await zipContent.files[fileName].async('blob');
            return {
                url: URL.createObjectURL(videoFile),
                fileName: fileName,
                size: videoFile.size
            };
        }
    }
    return null;
}

// פונקציה להצגת הודעת שגיאה
function showError(message) {
    previewError.textContent = message;
    previewError.style.display = 'block';
    previewVideo.style.display = 'none';
    previewInfo.style.display = 'none';
    previewLoading.style.display = 'none';
}

// פונקציה להסתרת התצוגה המקדימה
function hidePreview() {
    previewElement.style.display = 'none';
    if (previewVideo.src) {
        URL.revokeObjectURL(previewVideo.src);
        previewVideo.src = '';
    }
}

// מאזין ללחיצות על קישורים
document.addEventListener('click', async function(event) {
    const link = event.target.closest('a');
    if (!link) return;

    const url = link.href;
    if (!url.includes('prog.co.il/attachments/') || !url.toLowerCase().includes('-zip.')) return;

    event.preventDefault(); // מניעת ההורדה המקורית
    hidePreview(); // הסתרת התצוגה המקדימה אם היא מוצגת

    try {
        const result = await handleZipFile(url);
        if (result) {
            // בדיקת ההגדרות
            chrome.storage.sync.get(['playerMode'], function(settings) {
                const mode = settings.playerMode || 'floating';
                if (mode === 'floating') {
                    showFloatingPlayer(result.url, result.fileName);
                } else {
                    // פתיחת הוידאו בטאב חדש
                    const playerUrl = chrome.runtime.getURL('player.html');
                    chrome.runtime.sendMessage({ 
                        action: 'openVideoTab', 
                        url: playerUrl + '?video=' + encodeURIComponent(result.url)
                    });
                }
            });
        } else {
            showError('לא נמצא קובץ וידאו בארכיון');
        }
    } catch (error) {
        showError('שגיאה בטעינת הקובץ');
    }
});

// מאזינים לאירועי עכבר על קישורים
let previewTimeout;
document.addEventListener('mouseover', function(event) {
    const link = event.target.closest('a');
    if (!link) return;

    const url = link.href;
    if (!url.includes('prog.co.il/attachments/') || !url.toLowerCase().includes('-zip.')) return;

    // בדיקת ההגדרות לפני הפעלת התצוגה המקדימה
    chrome.storage.sync.get({ showPreview: true }, function(settings) {
        if (settings.showPreview) {
            clearTimeout(previewTimeout);
            previewTimeout = setTimeout(() => {
                const rect = link.getBoundingClientRect();
                showPreview(url, rect.right + 10, rect.top);
            }, 500);
        }
    });
});

document.addEventListener('mouseout', function(event) {
    const link = event.target.closest('a');
    if (!link) return;

    const url = link.href;
    if (!url.includes('prog.co.il/attachments/') || !url.toLowerCase().includes('-zip.')) return;

    clearTimeout(previewTimeout);
    hidePreview();
});

// פונקציה להצגת תצוגה מקדימה
async function showPreview(url, mouseX, mouseY) {
    previewElement.style.display = 'block';
    previewVideo.style.display = 'none';
    previewInfo.style.display = 'none';
    previewError.style.display = 'none';
    previewLoading.style.display = 'block';

    previewElement.style.left = mouseX + 'px';
    previewElement.style.top = mouseY + 'px';

    try {
        const result = await handleZipFile(url, true);
        if (result) {
            previewVideo.src = result.url;
            previewVideo.style.display = 'block';
            previewInfo.style.display = 'block';
            previewInfo.textContent = `${result.fileName}\nגודל: ${formatFileSize(result.size)}`;
            previewLoading.style.display = 'none';
            previewError.style.display = 'none';
        } else {
            showError('לא נמצא קובץ וידאו בארכיון');
        }
    } catch (error) {
        showError('שגיאה בטעינת התצוגה המקדימה');
    }
}

// פונקציה להמרת גודל קובץ
function formatFileSize(bytes) {
    if (bytes === 0) return '0 B';
    const k = 1024;
    const sizes = ['B', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
}

// פונקציה להצגת נגן צף
async function showFloatingPlayer(videoUrl, fileName) {
    try {
        // טעינת ההגדרות
        const settings = await new Promise(resolve => {
            chrome.storage.sync.get({
                windowWidth: 400,
                windowHeight: 300,
                windowPosition: 'bottom-right'
            }, (result) => {
                resolve(result);
            });
        });
        
        // הגדרת גודל החלון
        const width = settings.windowWidth;
        const height = settings.windowHeight;
        const position = settings.windowPosition;
        
        floatingPlayer.style.width = `${width}px`;
        floatingPlayer.style.height = `${height}px`;
        
        // איפוס כל המיקומים
        floatingPlayer.style.transform = 'none';
        floatingPlayer.style.top = 'auto';
        floatingPlayer.style.bottom = 'auto';
        floatingPlayer.style.left = 'auto';
        floatingPlayer.style.right = 'auto';
        
        const margin = '20px';
        
        switch (position) {
            case 'top-left':
                floatingPlayer.style.top = margin;
                floatingPlayer.style.right = margin;
                break;
            case 'top':
                floatingPlayer.style.top = margin;
                floatingPlayer.style.left = '50%';
                floatingPlayer.style.transform = 'translateX(-50%)';
                break;
            case 'top-right':
                floatingPlayer.style.top = margin;
                floatingPlayer.style.left = margin;
                break;
            case 'left':
                floatingPlayer.style.top = '50%';
                floatingPlayer.style.right = margin;
                floatingPlayer.style.transform = 'translateY(-50%)';
                break;
            case 'center':
                floatingPlayer.style.top = '50%';
                floatingPlayer.style.left = '50%';
                floatingPlayer.style.transform = 'translate(-50%, -50%)';
                break;
            case 'right':
                floatingPlayer.style.top = '50%';
                floatingPlayer.style.left = margin;
                floatingPlayer.style.transform = 'translateY(-50%)';
                break;
            case 'bottom-left':
                floatingPlayer.style.bottom = margin;
                floatingPlayer.style.right = margin;
                break;
            case 'bottom':
                floatingPlayer.style.bottom = margin;
                floatingPlayer.style.left = '50%';
                floatingPlayer.style.transform = 'translateX(-50%)';
                break;
            case 'bottom-right':
            default:
                floatingPlayer.style.bottom = margin;
                floatingPlayer.style.left = margin;
                break;
        }

        // המרת המיקום היחסי למיקום מוחלט
        setTimeout(() => {
            const rect = floatingPlayer.getBoundingClientRect();
            floatingPlayer.style.transform = 'none';
            floatingPlayer.style.top = rect.top + 'px';
            floatingPlayer.style.left = rect.left + 'px';
            floatingPlayer.style.bottom = 'auto';
            floatingPlayer.style.right = 'auto';
        }, 0);

        playerVideo.src = videoUrl;
        titleText.textContent = fileName;
        floatingPlayer.style.display = 'block';
        playerVideo.play();
        
    } catch (error) {
        previewError.textContent = 'שגיאה בהצגת הנגן';
        previewError.style.display = 'block';
    }
}

// יצירת אלמנטים לנגן הצף
const floatingPlayer = document.createElement('div');
floatingPlayer.style.cssText = `
    position: fixed;
    z-index: 10000;
    display: none;
    background: #000;
    border-radius: 8px;
    box-shadow: 0 4px 8px rgba(0,0,0,0.2);
    overflow: hidden;
    direction: ltr;
`;

const resizeHandles = `
    .resize-handle {
        position: absolute;
        background: transparent;
        z-index: 10001;
    }
    .resize-handle.top {
        top: -5px;
        left: 5px;
        right: 5px;
        height: 10px;
        cursor: n-resize;
    }
    .resize-handle.bottom {
        bottom: -5px;
        left: 5px;
        right: 5px;
        height: 10px;
        cursor: s-resize;
    }
    .resize-handle.left {
        left: -5px;
        top: 5px;
        bottom: 5px;
        width: 10px;
        cursor: w-resize;
    }
    .resize-handle.right {
        right: -5px;
        top: 5px;
        bottom: 5px;
        width: 10px;
        cursor: e-resize;
    }
    .resize-handle.top-left {
        top: -5px;
        left: -5px;
        width: 15px;
        height: 15px;
        cursor: nw-resize;
    }
    .resize-handle.top-right {
        top: -5px;
        right: -5px;
        width: 15px;
        height: 15px;
        cursor: ne-resize;
    }
    .resize-handle.bottom-left {
        bottom: -5px;
        left: -5px;
        width: 15px;
        height: 15px;
        cursor: sw-resize;
    }
    .resize-handle.bottom-right {
        bottom: -5px;
        right: -5px;
        width: 15px;
        height: 15px;
        cursor: se-resize;
    }
`;

const style = document.createElement('style');
style.textContent = resizeHandles;
document.head.appendChild(style);

// הוספת ידיות שינוי גודל
const positions = ['top', 'bottom', 'left', 'right', 'top-left', 'top-right', 'bottom-left', 'bottom-right'];
positions.forEach(pos => {
    const handle = document.createElement('div');
    handle.className = `resize-handle ${pos}`;
    floatingPlayer.appendChild(handle);
});

const playerTitle = document.createElement('div');
playerTitle.style.cssText = `
    padding: 8px;
    background: rgba(0,0,0,0.8);
    color: white;
    font-family: system-ui, -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
    cursor: move;
    display: flex;
    justify-content: space-between;
    align-items: center;
    direction: ltr;
    user-select: none;
`;

const controlsDiv = document.createElement('div');
controlsDiv.style.cssText = `
    display: flex;
    gap: 8px;
    margin-right: auto;
`;

const closeBtn = document.createElement('button');
closeBtn.innerHTML = '✕';
closeBtn.style.cssText = `
    background: none;
    border: none;
    color: white;
    cursor: pointer;
    padding: 4px;
`;

const fullscreenBtn = document.createElement('button');
fullscreenBtn.innerHTML = '⛶';
fullscreenBtn.style.cssText = `
    background: none;
    border: none;
    color: white;
    cursor: pointer;
    padding: 4px;
`;

controlsDiv.appendChild(closeBtn);
controlsDiv.appendChild(fullscreenBtn);
playerTitle.insertBefore(controlsDiv, playerTitle.firstChild);

const titleText = document.createElement('span');
titleText.style.cssText = `
    margin-left: 10px;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    direction: rtl;
`;
playerTitle.appendChild(titleText);

const playerVideo = document.createElement('video');
playerVideo.style.cssText = `
    width: 100%;
    height: calc(100% - 40px);
    display: block;
`;
playerVideo.controls = true;

floatingPlayer.appendChild(playerTitle);
floatingPlayer.appendChild(playerVideo);
document.body.appendChild(floatingPlayer);

// הוספת סגנונות למצב מסך מלא
const fullscreenStyles = document.createElement('style');
fullscreenStyles.textContent = `
    .floating-player-fullscreen {
        position: fixed !important;
        width: 100% !important;
        height: 100% !important;
        left: 0 !important;
        top: 0 !important;
        right: auto !important;
        bottom: auto !important;
        border-radius: 0;
        display: flex !important;
        flex-direction: column !important;
        background: #000;
        resize: none !important;
    }
    .floating-player-fullscreen > div:first-child {
        width: 100% !important;
        justify-content: space-between !important;
        padding: 12px 20px !important;
    }
    .floating-player-fullscreen video {
        width: auto !important;
        height: auto !important;
        max-width: 100% !important;
        max-height: calc(100vh - 60px) !important;
        margin: auto !important;
    }
`;
document.head.appendChild(fullscreenStyles);

// טיפול בלחיצה על כפתור מסך מלא
let isFullscreen = false;
let lastPosition = null; // שמירת המיקום האחרון לפני מסך מלא

fullscreenBtn.addEventListener('click', async () => {
    isFullscreen = !isFullscreen;
    floatingPlayer.classList.toggle('floating-player-fullscreen');
    
    if (isFullscreen) {
        // שמירת המיקום הנוכחי לפני המעבר למסך מלא
        lastPosition = {
            width: floatingPlayer.style.width,
            height: floatingPlayer.style.height,
            top: floatingPlayer.style.top,
            left: floatingPlayer.style.left,
            right: floatingPlayer.style.right,
            bottom: floatingPlayer.style.bottom,
            transform: floatingPlayer.style.transform
        };
        
        document.body.style.overflow = 'hidden';
        floatingPlayer.style.transform = 'none';
        floatingPlayer.style.top = '0';
        floatingPlayer.style.left = '0';
        floatingPlayer.style.right = 'auto';
        floatingPlayer.style.bottom = 'auto';
    } else {
        document.body.style.overflow = '';
        
        // בדיקת ההגדרות ושחזור המיקום
        if (lastPosition) {
            Object.assign(floatingPlayer.style, lastPosition);
        } else {
            // אם אין מיקום שמור, נשתמש בהגדרות
            const settings = await new Promise(resolve => {
                chrome.storage.sync.get({
                    windowWidth: 400,
                    windowHeight: 300,
                    windowPosition: 'bottom-right'
                }, resolve);
            });
            
            const margin = '20px';
            floatingPlayer.style.width = `${settings.windowWidth}px`;
            floatingPlayer.style.height = `${settings.windowHeight}px`;
            
            // איפוס כל המיקומים
            floatingPlayer.style.transform = 'none';
            floatingPlayer.style.top = 'auto';
            floatingPlayer.style.bottom = 'auto';
            floatingPlayer.style.left = 'auto';
            floatingPlayer.style.right = 'auto';
            
            switch (settings.windowPosition) {
                case 'top-left':
                    floatingPlayer.style.top = margin;
                    floatingPlayer.style.right = margin;
                    break;
                case 'top':
                    floatingPlayer.style.top = margin;
                    floatingPlayer.style.left = '50%';
                    floatingPlayer.style.transform = 'translateX(-50%)';
                    break;
                case 'top-right':
                    floatingPlayer.style.top = margin;
                    floatingPlayer.style.left = margin;
                    break;
                case 'left':
                    floatingPlayer.style.top = '50%';
                    floatingPlayer.style.right = margin;
                    floatingPlayer.style.transform = 'translateY(-50%)';
                    break;
                case 'center':
                    floatingPlayer.style.top = '50%';
                    floatingPlayer.style.left = '50%';
                    floatingPlayer.style.transform = 'translate(-50%, -50%)';
                    break;
                case 'right':
                    floatingPlayer.style.top = '50%';
                    floatingPlayer.style.left = margin;
                    floatingPlayer.style.transform = 'translateY(-50%)';
                    break;
                case 'bottom-left':
                    floatingPlayer.style.bottom = margin;
                    floatingPlayer.style.right = margin;
                    break;
                case 'bottom':
                    floatingPlayer.style.bottom = margin;
                    floatingPlayer.style.left = '50%';
                    floatingPlayer.style.transform = 'translateX(-50%)';
                    break;
                case 'bottom-right':
                default:
                    floatingPlayer.style.bottom = margin;
                    floatingPlayer.style.left = margin;
                    break;
            }
        }
    }
});

// הוספת מאזין למקשי מקלדת
document.addEventListener('keydown', function(event) {
    // בדיקה שהחלון הצף מוצג ושלא נמצאים במצב מסך מלא
    if (floatingPlayer.style.display === 'block' && !isFullscreen) {
        // קביעת מרחק התזוזה - עם Shift התזוזה גדולה יותר
        const step = event.shiftKey ? 50 : 10;
        const currentTop = parseInt(floatingPlayer.style.top) || 0;
        const currentLeft = parseInt(floatingPlayer.style.left) || 0;

        switch (event.key) {
            case 'ArrowUp':
                // מניעת גלילת הדף
                event.preventDefault();
                floatingPlayer.style.top = Math.max(0, currentTop - step) + 'px';
                break;
            case 'ArrowDown':
                event.preventDefault();
                floatingPlayer.style.top = Math.min(
                    window.innerHeight - floatingPlayer.offsetHeight,
                    currentTop + step
                ) + 'px';
                break;
            case 'ArrowLeft':
                event.preventDefault();
                floatingPlayer.style.left = Math.max(0, currentLeft - step) + 'px';
                break;
            case 'ArrowRight':
                event.preventDefault();
                floatingPlayer.style.left = Math.min(
                    window.innerWidth - floatingPlayer.offsetWidth,
                    currentLeft + step
                ) + 'px';
                break;
        }
    }
});

// עדכון פונקציות הגרירה והשינוי גודל
let isDragging = false;
let isResizing = false;
let currentHandle = null;
let startX = 0;
let startY = 0;
let startWidth = 0;
let startHeight = 0;
let startLeft = 0;
let startTop = 0;

playerTitle.addEventListener('mousedown', (e) => {
    if (!isFullscreen) {
        isDragging = true;
        const rect = floatingPlayer.getBoundingClientRect();
        startX = e.clientX - rect.left;
        startY = e.clientY - rect.top;
        e.preventDefault();
    }
});

floatingPlayer.querySelectorAll('.resize-handle').forEach(handle => {
    handle.addEventListener('mousedown', (e) => {
        if (!isFullscreen) {
            isResizing = true;
            currentHandle = handle;
            const rect = floatingPlayer.getBoundingClientRect();
            startX = e.clientX;
            startY = e.clientY;
            startWidth = rect.width;
            startHeight = rect.height;
            startLeft = rect.left;
            startTop = rect.top;
            e.preventDefault();
            e.stopPropagation();
        }
    });
});

document.addEventListener('mousemove', (e) => {
    if (isDragging) {
        const newLeft = e.clientX - startX;
        const newTop = e.clientY - startY;
        
        // הגבלת הגרירה לגבולות המסך
        const rect = floatingPlayer.getBoundingClientRect();
        const maxX = window.innerWidth - rect.width;
        const maxY = window.innerHeight - rect.height;
        
        floatingPlayer.style.left = `${Math.min(Math.max(0, newLeft), maxX)}px`;
        floatingPlayer.style.top = `${Math.min(Math.max(0, newTop), maxY)}px`;
        
    } else if (isResizing && currentHandle) {
        const minWidth = 300;
        const minHeight = 200;
        const rect = floatingPlayer.getBoundingClientRect();
        const deltaX = e.clientX - startX;
        const deltaY = e.clientY - startY;
        
        let newWidth = startWidth;
        let newHeight = startHeight;
        let newLeft = startLeft;
        let newTop = startTop;
        
        if (currentHandle.classList.contains('right') || 
            currentHandle.classList.contains('top-right') || 
            currentHandle.classList.contains('bottom-right')) {
            newWidth = Math.max(minWidth, startWidth + deltaX);
        }
        if (currentHandle.classList.contains('left') || 
            currentHandle.classList.contains('top-left') || 
            currentHandle.classList.contains('bottom-left')) {
            const possibleWidth = Math.max(minWidth, startWidth - deltaX);
            if (possibleWidth !== minWidth) {
                newLeft = startLeft + deltaX;
                newWidth = possibleWidth;
            }
        }
        if (currentHandle.classList.contains('bottom') || 
            currentHandle.classList.contains('bottom-left') || 
            currentHandle.classList.contains('bottom-right')) {
            newHeight = Math.max(minHeight, startHeight + deltaY);
        }
        if (currentHandle.classList.contains('top') || 
            currentHandle.classList.contains('top-left') || 
            currentHandle.classList.contains('top-right')) {
            const possibleHeight = Math.max(minHeight, startHeight - deltaY);
            if (possibleHeight !== minHeight) {
                newTop = startTop + deltaY;
                newHeight = possibleHeight;
            }
        }
        
        // הגבלת הגודל לגבולות המסך
        if (newLeft + newWidth > window.innerWidth) {
            newWidth = window.innerWidth - newLeft;
        }
        if (newTop + newHeight > window.innerHeight) {
            newHeight = window.innerHeight - newTop;
        }
        
        floatingPlayer.style.width = `${newWidth}px`;
        floatingPlayer.style.height = `${newHeight}px`;
        floatingPlayer.style.left = `${newLeft}px`;
        floatingPlayer.style.top = `${newTop}px`;
    }
});

document.addEventListener('mouseup', () => {
    isDragging = false;
    isResizing = false;
    currentHandle = null;
});

// טיפול בלחיצה על כפתור סגירה
closeBtn.addEventListener('click', () => {
    if (isFullscreen) {
        isFullscreen = false;
        floatingPlayer.classList.remove('floating-player-fullscreen');
        document.body.style.overflow = '';
    }
    floatingPlayer.style.display = 'none';
    playerVideo.pause();
    playerVideo.src = '';
});
